Configuring Amazon S3.
======================

Ask for your sysadmin that configure a bucket for you and an IAM with write
access to that specific bucket, once it is done ask him to configure such
bucket with a domain.

This is not an End User task, so I supose you should ask for help in google all
the topics above are explained in the Amazon Documentation.

TODO: detailed explanation.
TODO: explain **saving money**


